@@ -1,8 +1,7 @@
-// -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; indent-tabs-mode: nil; -*-
-//
+
 //  RQuantLib -- R interface to the QuantLib libraries
 //
-//  Copyright (C) 2002 - 2018  Dirk Eddelbuettel 
+//  Copyright (C) 2002 - 2019  Dirk Eddelbuettel
 //  Copyright (C) 2010         Dirk Eddelbuettel and Khanh Nguyen
 //
 //  RQuantLib is free software: you can redistribute it and/or modify
@@ -21,18 +20,18 @@
 #include <rquantlib_internal.h>
 
 // returns a reference-counted pointer to a matching Calendar object
-boost::shared_ptr<QuantLib::Calendar> getCalendar(const std::string &calstr) {
-    boost::shared_ptr<QuantLib::Calendar> pcal;
+QuantLib::ext::shared_ptr<QuantLib::Calendar> getCalendar(const std::string &calstr) {
+    QuantLib::ext::shared_ptr<QuantLib::Calendar> pcal;
 
-    if (calstr == "TARGET") { 		// generic calendar 
+    if (calstr == "TARGET") { 		// generic calendar
         pcal.reset(new QuantLib::TARGET());
-        
+
     } else if (calstr == "Argentina") {
         pcal.reset(new QuantLib::Argentina());
 
     } else if (calstr == "Australia") {
         pcal.reset(new QuantLib::Australia());
-        
+
     } else if (calstr == "Brazil") {
         pcal.reset(new QuantLib::Brazil());
 
@@ -43,7 +42,7 @@ boost::shared_ptr<QuantLib::Calendar> getCalendar(const std::string &calstr) {
 
     } else if (calstr == "China") {
         pcal.reset(new QuantLib::China());
-      
+
     } else if (calstr == "CzechRepublic") {
         pcal.reset(new QuantLib::CzechRepublic());
 
@@ -52,7 +51,7 @@ boost::shared_ptr<QuantLib::Calendar> getCalendar(const std::string &calstr) {
 
     } else if (calstr == "Finland") {
         pcal.reset(new QuantLib::Finland());
-        
+
     } else if (calstr == "Germany" || calstr == "Germany/FrankfurtStockExchange") {
         pcal.reset(new QuantLib::Germany(QuantLib::Germany::FrankfurtStockExchange));
     } else if (calstr == "Germany/Settlement") {
@@ -61,7 +60,7 @@ boost::shared_ptr<QuantLib::Calendar> getCalendar(const std::string &calstr) {
         pcal.reset(new QuantLib::Germany(QuantLib::Germany::Xetra));
     } else if (calstr == "Germany/Eurex") {
         pcal.reset(new QuantLib::Germany(QuantLib::Germany::Eurex));
-        
+
     } else if (calstr == "HongKong") {
         pcal.reset(new QuantLib::HongKong());
 
@@ -76,18 +75,18 @@ boost::shared_ptr<QuantLib::Calendar> getCalendar(const std::string &calstr) {
 
     } else if (calstr == "Indonesia") {
         pcal.reset(new QuantLib::Indonesia());
-        
+
     } else if (calstr == "Italy" || calstr == "Italy/Settlement") {
         pcal.reset(new QuantLib::Italy(QuantLib::Italy::Settlement));
     } else if (calstr == "Italy/Exchange") {
         pcal.reset(new QuantLib::Italy(QuantLib::Italy::Exchange));
-        
+
     } else if (calstr == "Japan" || calstr == "Japan/Settlement") {
         pcal.reset(new QuantLib::Japan());
 
     } else if (calstr == "Mexico") {
         pcal.reset(new QuantLib::Mexico());
-        
+
     } else if (calstr == "NewZealand") {
         pcal.reset(new QuantLib::NewZealand());
 
@@ -111,7 +110,7 @@ boost::shared_ptr<QuantLib::Calendar> getCalendar(const std::string &calstr) {
 
     } else if (calstr == "SouthAfrica") {
         pcal.reset(new QuantLib::SouthAfrica());
-        
+
     } else if (calstr == "SouthKorea" || calstr == "SouthKorea/Settlement") {
         pcal.reset(new QuantLib::SouthKorea(QuantLib::SouthKorea::Settlement));
     } else if (calstr == "SouthKorea/KRX") {
@@ -138,7 +137,7 @@ boost::shared_ptr<QuantLib::Calendar> getCalendar(const std::string &calstr) {
         pcal.reset(new QuantLib::UnitedKingdom(QuantLib::UnitedKingdom::Exchange));
     } else if (calstr == "UnitedKingdom/Metals") {
         pcal.reset(new QuantLib::UnitedKingdom(QuantLib::UnitedKingdom::Metals));
-        
+
     } else if (calstr == "UnitedStates" || calstr == "UnitedStates/Settlement") {
         pcal.reset(new QuantLib::UnitedStates(QuantLib::UnitedStates::Settlement));
     } else if (calstr == "UnitedStates/NYSE") {
@@ -151,6 +150,9 @@ boost::shared_ptr<QuantLib::Calendar> getCalendar(const std::string &calstr) {
     } else if (calstr == "WeekendsOnly") {
         pcal.reset(new QuantLib::WeekendsOnly());
 
+    } else if (calstr == "Null" || calstr == "null" || calstr == "NULL") {
+        pcal.reset(new QuantLib::NullCalendar());
+
     } else {
         throw std::invalid_argument("Calendar " + calstr + " not recognised ");
     }
@@ -169,21 +171,21 @@ bool setCalendarContext(std::string calendar, int fixingDays, QuantLib::Date set
     if (settleDate.serialNumber() == 0) {
         calendar = "TARGET";
         fixingDays = 2;
-        settleDate = QuantLib::Date::todaysDate() + 2; 
+        settleDate = QuantLib::Date::todaysDate() + 2;
     }
     // set fixingDays and settleDate
     RQLContext::instance().fixingDays = fixingDays;
     RQLContext::instance().settleDate = settleDate;
 
-    boost::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
+    QuantLib::ext::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
     RQLContext::instance().calendar = *pcal; // set calendar in global singleton
-    
+
     return true;
 }
 
 // [[Rcpp::export]]
 std::vector<bool> isBusinessDay(std::string calendar, std::vector<QuantLib::Date> dates) {
-    boost::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
+    QuantLib::ext::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
     int n = dates.size();
     std::vector<bool> bizdays(n);
     for (int i=0; i<n; i++) {
@@ -194,7 +196,7 @@ std::vector<bool> isBusinessDay(std::string calendar, std::vector<QuantLib::Date
 
 // [[Rcpp::export]]
 std::vector<bool> isHoliday(std::string calendar, std::vector<QuantLib::Date> dates) {
-    boost::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
+    QuantLib::ext::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
     int n = dates.size();
     std::vector<bool> hdays(n);
     for (int i=0; i<n; i++) {
@@ -205,7 +207,7 @@ std::vector<bool> isHoliday(std::string calendar, std::vector<QuantLib::Date> da
 
 // [[Rcpp::export]]
 std::vector<bool> isWeekend(std::string calendar, std::vector<QuantLib::Date> dates) {
-    boost::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
+    QuantLib::ext::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
     int n = dates.size();
     std::vector<bool> weekends(n);
     for (int i=0; i<n; i++) {
@@ -216,7 +218,7 @@ std::vector<bool> isWeekend(std::string calendar, std::vector<QuantLib::Date> da
 
 // [[Rcpp::export]]
 std::vector<bool> isEndOfMonth(std::string calendar, std::vector<QuantLib::Date> dates) {
-    boost::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
+    QuantLib::ext::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
     int n = dates.size();
     std::vector<bool> eom(n);
     for (int i=0; i<n; i++) {
@@ -227,7 +229,7 @@ std::vector<bool> isEndOfMonth(std::string calendar, std::vector<QuantLib::Date>
 
 // [[Rcpp::export]]
 std::vector<QuantLib::Date> getEndOfMonth(std::string calendar, std::vector<QuantLib::Date> dates) {
-    boost::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
+    QuantLib::ext::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
     int n = dates.size();
     std::vector<QuantLib::Date> ndates(n);
     for (int i=0; i<n; i++) {
@@ -238,7 +240,7 @@ std::vector<QuantLib::Date> getEndOfMonth(std::string calendar, std::vector<Quan
 
 // [[Rcpp::export]]
 std::vector<QuantLib::Date> adjust(std::string calendar, std::vector<QuantLib::Date> dates, int bdc=0) {
-    boost::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
+    QuantLib::ext::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
     QuantLib::BusinessDayConvention bdcval = getBusinessDayConvention(bdc);
     int n = dates.size();
     std::vector<QuantLib::Date> adjusted(n);
@@ -249,15 +251,15 @@ std::vector<QuantLib::Date> adjust(std::string calendar, std::vector<QuantLib::D
 }
 
 // [[Rcpp::export]]
-std::vector<QuantLib::Date> advance1(std::string calendar, 
-         double amount, double unit, int bdcVal, double emr, 
+std::vector<QuantLib::Date> advance1(std::string calendar,
+         double amount, double unit, int bdcVal, double emr,
          std::vector<QuantLib::Date> dates) {
 
-    boost::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
+    QuantLib::ext::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
     QuantLib::BusinessDayConvention bdc = getBusinessDayConvention(bdcVal);
     int n = dates.size();
     std::vector<QuantLib::Date> advance(n);
-    
+
     for (int i=0; i<n; i++) {
         advance[i] = pcal->advance(dates[i], amount, getTimeUnit(unit), bdc, (emr == 1) ? true : false);
     }
@@ -265,28 +267,28 @@ std::vector<QuantLib::Date> advance1(std::string calendar,
 }
 
 // [[Rcpp::export]]
-std::vector<QuantLib::Date> advance2(std::string calendar, 
-                                     double period, int bdcVal, double emr, 
+std::vector<QuantLib::Date> advance2(std::string calendar,
+                                     double period, int bdcVal, double emr,
                                      std::vector<QuantLib::Date> dates) {
 
-    boost::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
+    QuantLib::ext::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
     QuantLib::BusinessDayConvention bdc = getBusinessDayConvention(bdcVal);
     int n = dates.size();
     std::vector<QuantLib::Date> advance(n);
 
     for (int i=0; i<n; i++) {
-        advance[i] = pcal->advance(dates[i], QuantLib::Period(getFrequency(period)), 
+        advance[i] = pcal->advance(dates[i], QuantLib::Period(getFrequency(period)),
                                    bdc, (emr == 1) ? true : false);
     }
     return advance;
 }
 
 // [[Rcpp::export]]
-std::vector<double> businessDaysBetween(std::string calendar, 
-                                        std::vector<QuantLib::Date> from, 
+std::vector<double> businessDaysBetween(std::string calendar,
+                                        std::vector<QuantLib::Date> from,
                                         std::vector<QuantLib::Date> to,
                                         bool includeFirst=true, bool includeLast=false) {
-    boost::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
+    QuantLib::ext::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
     int n = from.size();
     std::vector<double> between(n);
     for (int i=0; i<n; i++) {
@@ -296,18 +298,18 @@ std::vector<double> businessDaysBetween(std::string calendar,
 }
 
 // [[Rcpp::export]]
-std::vector<QuantLib::Date> getHolidayList(std::string calendar, 
+std::vector<QuantLib::Date> getHolidayList(std::string calendar,
                                            QuantLib::Date from, QuantLib::Date to,
                                            bool includeWeekends=false) {
 
-    boost::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
+    QuantLib::ext::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
     std::vector<QuantLib::Date> holidays = QuantLib::Calendar::holidayList(*pcal, from, to, includeWeekends);
     return holidays;
 }
 
 // [[Rcpp::export]]
 void addHolidays(std::string calendar, std::vector<QuantLib::Date> dates) {
-    boost::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
+    QuantLib::ext::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
     int n = dates.size();
     for (int i=0; i<n; i++) {
         pcal->addHoliday(dates[i]);
@@ -316,7 +318,7 @@ void addHolidays(std::string calendar, std::vector<QuantLib::Date> dates) {
 
 // [[Rcpp::export]]
 void removeHolidays(std::string calendar, std::vector<QuantLib::Date> dates) {
-    boost::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
+    QuantLib::ext::shared_ptr<QuantLib::Calendar> pcal(getCalendar(calendar));
     int n = dates.size();
     for (int i=0; i<n; i++) {
         pcal->removeHoliday(dates[i]);
