@@ -1,9 +1,8 @@
-// -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; indent-tabs-mode: nil; -*-
-//
+
 //  RQuantLib -- R interface to the QuantLib libraries
 //
 //  Copyright (C) 2005 - 2007  Dominick Samperi
-//  Copyright (C) 2007 - 2018  Dirk Eddelbuettel
+//  Copyright (C) 2007 - 2019  Dirk Eddelbuettel
 //
 //  This file is part of RQuantLib.
 //
@@ -70,7 +69,7 @@ ObservableDB::ObservableDB() {
 
 // Get RateHelper used to build the yield curve corresponding to a
 // database key ('ticker') and observed rate/price.
-boost::shared_ptr<QuantLib::RateHelper> 
+QuantLib::ext::shared_ptr<QuantLib::RateHelper>
 ObservableDB::getRateHelper(std::string& ticker, QuantLib::Rate r, double fixDayCount,
                             double fixFreq, int floatFreq) {
     RQLMapIterator iter = db_.find(ticker);
@@ -82,29 +81,29 @@ ObservableDB::getRateHelper(std::string& ticker, QuantLib::Rate r, double fixDay
     RQLObservableType type = p->getType();
     int n1 = p->getN1(), n2 = p->getN2();
     QuantLib::TimeUnit units = p->getUnits();
-    
+
     QuantLib::Date settlementDate = RQLContext::instance().settleDate;
     QuantLib::Calendar calendar = RQLContext::instance().calendar;
     QuantLib::Integer fixingDays = RQLContext::instance().fixingDays;
     QuantLib::DayCounter depositDayCounter = QuantLib::Actual360();
-    
+
     // Tried to use a switch statement here, but there was an
     // internal compiler error using g++ Version 3.2.2.
     if (type == RQLDeposit) {
-        boost::shared_ptr<QuantLib::Quote> quote(new QuantLib::SimpleQuote(r));
-        boost::shared_ptr<QuantLib::RateHelper> 
+        QuantLib::ext::shared_ptr<QuantLib::Quote> quote(new QuantLib::SimpleQuote(r));
+        QuantLib::ext::shared_ptr<QuantLib::RateHelper>
             depo(new QuantLib::DepositRateHelper(QuantLib::Handle<QuantLib::Quote>(quote),
-                                                 n1*units, fixingDays,      
-                                                 calendar, QuantLib::ModifiedFollowing, 
+                                                 n1*units, fixingDays,
+                                                 calendar, QuantLib::ModifiedFollowing,
                                                  true, /*fixingDays,*/ depositDayCounter));
         return depo;
     } else if (type == RQLSwap) {
         QuantLib::Frequency swFixedLegFrequency = getFrequency(fixFreq);
         QuantLib::BusinessDayConvention swFixedLegConvention = QuantLib::Unadjusted;
         QuantLib::DayCounter swFixedLegDayCounter = getDayCounter(fixDayCount);
-        boost::shared_ptr<QuantLib::IborIndex> swFloatingLegIndex(new QuantLib::Euribor(QuantLib::Period(floatFreq,QuantLib::Months)));
-        boost::shared_ptr<QuantLib::Quote> quote(new QuantLib::SimpleQuote(r));
-        boost::shared_ptr<QuantLib::RateHelper> 
+        QuantLib::ext::shared_ptr<QuantLib::IborIndex> swFloatingLegIndex(new QuantLib::Euribor(QuantLib::Period(floatFreq,QuantLib::Months)));
+        QuantLib::ext::shared_ptr<QuantLib::Quote> quote(new QuantLib::SimpleQuote(r));
+        QuantLib::ext::shared_ptr<QuantLib::RateHelper>
             swap(new QuantLib::SwapRateHelper(QuantLib::Handle<QuantLib::Quote>(quote),
                                               n1*QuantLib::Years, /*fixingDays,*/
                                               calendar, swFixedLegFrequency,
@@ -117,19 +116,19 @@ ObservableDB::getRateHelper(std::string& ticker, QuantLib::Rate r, double fixDay
         for (int i = 1; i < n1; i++)
             imm = QuantLib::IMM::nextDate(imm+1);
         //Rcpp::Rcout << "Curves: IMM Date is " << imm << std::endl;
-        boost::shared_ptr<QuantLib::Quote> quote(new QuantLib::SimpleQuote(r));
-        boost::shared_ptr<QuantLib::RateHelper> 
+        QuantLib::ext::shared_ptr<QuantLib::Quote> quote(new QuantLib::SimpleQuote(r));
+        QuantLib::ext::shared_ptr<QuantLib::RateHelper>
             future(new QuantLib::FuturesRateHelper(QuantLib::Handle<QuantLib::Quote>(quote),
-                                                   imm, futMonths, calendar, 
+                                                   imm, futMonths, calendar,
                                                    QuantLib::ModifiedFollowing,
                                                    true, // added bool endOfMonth variable
                                                    depositDayCounter));
         return future;
     } else if (type == RQLFRA) {
-        boost::shared_ptr<QuantLib::Quote> quote(new QuantLib::SimpleQuote(r));
-        boost::shared_ptr<QuantLib::RateHelper> 
+        QuantLib::ext::shared_ptr<QuantLib::Quote> quote(new QuantLib::SimpleQuote(r));
+        QuantLib::ext::shared_ptr<QuantLib::RateHelper>
             FRA(new QuantLib::FraRateHelper(QuantLib::Handle<QuantLib::Quote>(quote),
-                                            n1, n2, fixingDays, calendar, 
+                                            n1, n2, fixingDays, calendar,
                                             QuantLib::ModifiedFollowing,
                                             true, /*fixingDays,*/ depositDayCounter));
         return FRA;
@@ -137,12 +136,12 @@ ObservableDB::getRateHelper(std::string& ticker, QuantLib::Rate r, double fixDay
         Rcpp::stop("Bad type in curve construction");
     }
     // not reached
-    boost::shared_ptr<QuantLib::RateHelper> tmp;
+    QuantLib::ext::shared_ptr<QuantLib::RateHelper> tmp;
     return tmp;
 }
 
 //*** original rate helper, kept to ensure Bermudan works. Change in future - Terry Leitch 16 Mar '16
-boost::shared_ptr<QuantLib::RateHelper> 
+QuantLib::ext::shared_ptr<QuantLib::RateHelper>
 ObservableDB::getRateHelper(std::string& ticker, QuantLib::Rate r) {
     RQLMapIterator iter = db_.find(ticker);
     if (iter == db_.end()) {
@@ -153,29 +152,29 @@ ObservableDB::getRateHelper(std::string& ticker, QuantLib::Rate r) {
     RQLObservableType type = p->getType();
     int n1 = p->getN1(), n2 = p->getN2();
     QuantLib::TimeUnit units = p->getUnits();
-    
+
     QuantLib::Date settlementDate = RQLContext::instance().settleDate;
     QuantLib::Calendar calendar = RQLContext::instance().calendar;
     QuantLib::Integer fixingDays = RQLContext::instance().fixingDays;
     QuantLib::DayCounter depositDayCounter = QuantLib::Actual360();
-    
+
     // Tried to use a switch statement here, but there was an
     // internal compiler error using g++ Version 3.2.2.
     if (type == RQLDeposit) {
-        boost::shared_ptr<QuantLib::Quote> quote(new QuantLib::SimpleQuote(r));
-        boost::shared_ptr<QuantLib::RateHelper> 
+        QuantLib::ext::shared_ptr<QuantLib::Quote> quote(new QuantLib::SimpleQuote(r));
+        QuantLib::ext::shared_ptr<QuantLib::RateHelper>
             depo(new QuantLib::DepositRateHelper(QuantLib::Handle<QuantLib::Quote>(quote),
-                                                 n1*units, fixingDays,      
-                                                 calendar, QuantLib::ModifiedFollowing, 
+                                                 n1*units, fixingDays,
+                                                 calendar, QuantLib::ModifiedFollowing,
                                                  true, /*fixingDays,*/ depositDayCounter));
         return depo;
     } else if (type == RQLSwap) {
         QuantLib::Frequency swFixedLegFrequency = QuantLib::Annual;
         QuantLib::BusinessDayConvention swFixedLegConvention = QuantLib::Unadjusted;
         QuantLib::DayCounter swFixedLegDayCounter = QuantLib::Thirty360(QuantLib::Thirty360::European);
-        boost::shared_ptr<QuantLib::IborIndex> swFloatingLegIndex(new QuantLib::Euribor6M);
-        boost::shared_ptr<QuantLib::Quote> quote(new QuantLib::SimpleQuote(r));
-        boost::shared_ptr<QuantLib::RateHelper> 
+        QuantLib::ext::shared_ptr<QuantLib::IborIndex> swFloatingLegIndex(new QuantLib::Euribor6M);
+        QuantLib::ext::shared_ptr<QuantLib::Quote> quote(new QuantLib::SimpleQuote(r));
+        QuantLib::ext::shared_ptr<QuantLib::RateHelper>
             swap(new QuantLib::SwapRateHelper(QuantLib::Handle<QuantLib::Quote>(quote),
                                               n1*QuantLib::Years, /*fixingDays,*/
                                               calendar, swFixedLegFrequency,
@@ -188,19 +187,19 @@ ObservableDB::getRateHelper(std::string& ticker, QuantLib::Rate r) {
         for (int i = 1; i < n1; i++)
             imm = QuantLib::IMM::nextDate(imm+1);
         //Rcpp::Rcout << "Curves: IMM Date is " << imm << std::endl;
-        boost::shared_ptr<QuantLib::Quote> quote(new QuantLib::SimpleQuote(r));
-        boost::shared_ptr<QuantLib::RateHelper> 
+        QuantLib::ext::shared_ptr<QuantLib::Quote> quote(new QuantLib::SimpleQuote(r));
+        QuantLib::ext::shared_ptr<QuantLib::RateHelper>
             future(new QuantLib::FuturesRateHelper(QuantLib::Handle<QuantLib::Quote>(quote),
-                                                   imm, futMonths, calendar, 
+                                                   imm, futMonths, calendar,
                                                    QuantLib::ModifiedFollowing,
                                                    true, // added bool endOfMonth variable
                                                    depositDayCounter));
         return future;
     } else if (type == RQLFRA) {
-        boost::shared_ptr<QuantLib::Quote> quote(new QuantLib::SimpleQuote(r));
-        boost::shared_ptr<QuantLib::RateHelper> 
+        QuantLib::ext::shared_ptr<QuantLib::Quote> quote(new QuantLib::SimpleQuote(r));
+        QuantLib::ext::shared_ptr<QuantLib::RateHelper>
             FRA(new QuantLib::FraRateHelper(QuantLib::Handle<QuantLib::Quote>(quote),
-                                            n1, n2, fixingDays, calendar, 
+                                            n1, n2, fixingDays, calendar,
                                             QuantLib::ModifiedFollowing,
                                             true, /*fixingDays,*/ depositDayCounter));
         return FRA;
@@ -208,7 +207,7 @@ ObservableDB::getRateHelper(std::string& ticker, QuantLib::Rate r) {
         Rcpp::stop("Bad type in curve construction");
     }
     // not reached
-    boost::shared_ptr<QuantLib::RateHelper> tmp;
+    QuantLib::ext::shared_ptr<QuantLib::RateHelper> tmp;
     return tmp;
 }
 
@@ -216,92 +215,92 @@ ObservableDB::getRateHelper(std::string& ticker, QuantLib::Rate r) {
 
 // Return the term structure built using a set of RateHelpers (curveInput)
 // employing the specified interpolation method and day counter.
-boost::shared_ptr<QuantLib::YieldTermStructure> 
-getTermStructure (std::string& interpWhat, std::string& interpHow, 
+QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure>
+getTermStructure (std::string& interpWhat, std::string& interpHow,
                   const QuantLib::Date& settlementDate,
-                  const std::vector<boost::shared_ptr<QuantLib::RateHelper> >& curveInput,
+                  const std::vector<QuantLib::ext::shared_ptr<QuantLib::RateHelper> >& curveInput,
                   QuantLib::DayCounter& dayCounter, QuantLib::Real tolerance) {
-    
+
     // the identifiers are just too bloody long so this functions like a 120 col or so display
-    
+
     if (interpWhat.compare("discount") == 0 && interpHow.compare("linear") == 0) {
-        boost::shared_ptr<QuantLib::YieldTermStructure> 
-            ts(new QuantLib::PiecewiseYieldCurve<QuantLib::Discount, 
-               QuantLib::Linear>(settlementDate, 
-                                 curveInput, dayCounter, 
+        QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure>
+            ts(new QuantLib::PiecewiseYieldCurve<QuantLib::Discount,
+               QuantLib::Linear>(settlementDate,
+                                 curveInput, dayCounter,
                                  std::vector<QuantLib::Handle<QuantLib::Quote> >(),
                                  std::vector<QuantLib::Date>(),
                                  tolerance));
         return ts;
     } else if (interpWhat.compare("discount") == 0 && interpHow.compare("loglinear") == 0) {
-        boost::shared_ptr<QuantLib::YieldTermStructure> 
+        QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure>
             ts(new QuantLib::PiecewiseYieldCurve<QuantLib::Discount,
-               QuantLib::LogLinear>(settlementDate, 
-                                    curveInput, dayCounter, 
+               QuantLib::LogLinear>(settlementDate,
+                                    curveInput, dayCounter,
                                     std::vector<QuantLib::Handle<QuantLib::Quote> >(),
                                     std::vector<QuantLib::Date>(),
                                     tolerance));
         return ts;
     } else if (interpWhat.compare("discount") == 0 && interpHow.compare("spline") == 0) {
-        boost::shared_ptr<QuantLib::YieldTermStructure> 
-            ts(new QuantLib::PiecewiseYieldCurve<QuantLib::Discount, 
-               QuantLib::Cubic>(settlementDate, 
-                                curveInput, dayCounter, 
+        QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure>
+            ts(new QuantLib::PiecewiseYieldCurve<QuantLib::Discount,
+               QuantLib::Cubic>(settlementDate,
+                                curveInput, dayCounter,
                                 std::vector<QuantLib::Handle<QuantLib::Quote> >(),
                                 std::vector<QuantLib::Date>(),
                                 tolerance));
         return ts;
     } else if (interpWhat.compare("forward") == 0 &&
                interpHow.compare("linear") == 0) {
-        boost::shared_ptr<QuantLib::YieldTermStructure> 
-            ts(new QuantLib::PiecewiseYieldCurve<QuantLib::ForwardRate, 
-               QuantLib::Linear>(settlementDate, 
-                                 curveInput, dayCounter, 
+        QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure>
+            ts(new QuantLib::PiecewiseYieldCurve<QuantLib::ForwardRate,
+               QuantLib::Linear>(settlementDate,
+                                 curveInput, dayCounter,
                                  std::vector<QuantLib::Handle<QuantLib::Quote> >(),
                                  std::vector<QuantLib::Date>(),
                                  tolerance));
         return ts;
     } else if (interpWhat.compare("forward") == 0 && interpHow.compare("loglinear") == 0) {
-        boost::shared_ptr<QuantLib::YieldTermStructure> 
+        QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure>
             ts(new QuantLib::PiecewiseYieldCurve<QuantLib::ForwardRate,
-               QuantLib::LogLinear>(settlementDate, 
-                                    curveInput, dayCounter, 
+               QuantLib::LogLinear>(settlementDate,
+                                    curveInput, dayCounter,
                                     std::vector<QuantLib::Handle<QuantLib::Quote> >(),
                                     std::vector<QuantLib::Date>(),
                                     tolerance));
         return ts;
     } else if (interpWhat.compare("forward") == 0 && interpHow.compare("spline") == 0) {
-        boost::shared_ptr<QuantLib::YieldTermStructure> 
+        QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure>
             ts(new QuantLib::PiecewiseYieldCurve<QuantLib::ForwardRate,
-               QuantLib::Cubic>(settlementDate, 
-                                curveInput, dayCounter, 
+               QuantLib::Cubic>(settlementDate,
+                                curveInput, dayCounter,
                                 std::vector<QuantLib::Handle<QuantLib::Quote> >(),
                                 std::vector<QuantLib::Date>(),
                                 tolerance));
         return ts;
     } else if (interpWhat.compare("zero") == 0 && interpHow.compare("linear") == 0) {
-        boost::shared_ptr<QuantLib::YieldTermStructure> 
+        QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure>
             ts(new QuantLib::PiecewiseYieldCurve<QuantLib::ZeroYield,
-               QuantLib::Linear>(settlementDate, 
-                                 curveInput, dayCounter, 
+               QuantLib::Linear>(settlementDate,
+                                 curveInput, dayCounter,
                                  std::vector<QuantLib::Handle<QuantLib::Quote> >(),
                                  std::vector<QuantLib::Date>(),
                                  tolerance));
         return ts;
     } else if (interpWhat.compare("zero") == 0 && interpHow.compare("loglinear") == 0) {
-        boost::shared_ptr<QuantLib::YieldTermStructure> 
+        QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure>
             ts(new QuantLib::PiecewiseYieldCurve<QuantLib::ZeroYield,
-               QuantLib::LogLinear>(settlementDate, 
-                                    curveInput, dayCounter, 
+               QuantLib::LogLinear>(settlementDate,
+                                    curveInput, dayCounter,
                                     std::vector<QuantLib::Handle<QuantLib::Quote> >(),
                                     std::vector<QuantLib::Date>(),
                                     tolerance));
         return ts;
     } else if (interpWhat.compare("zero") == 0 && interpHow.compare("spline") == 0) {
-        boost::shared_ptr<QuantLib::YieldTermStructure> 
+        QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure>
             ts(new QuantLib::PiecewiseYieldCurve<QuantLib::ZeroYield,
-               QuantLib::Cubic>(settlementDate, 
-                                curveInput, dayCounter, 
+               QuantLib::Cubic>(settlementDate,
+                                curveInput, dayCounter,
                                 std::vector<QuantLib::Handle<QuantLib::Quote> >(),
                                 std::vector<QuantLib::Date>(),
                                 tolerance));
@@ -312,6 +311,6 @@ getTermStructure (std::string& interpWhat, std::string& interpHow,
         Rcpp::stop("What/How term structure options not recognized");
     }
     // not reached -- just here to make g++ -pendantic happy
-    boost::shared_ptr<QuantLib::YieldTermStructure> tmp;
+    QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure> tmp;
     return tmp;
 }
